(function (window, document, angular) {
	'use strict';
	angular.module('app', ['pascalprecht.translate'])
		.run(['$rootScope', function($rootScope, $location) {
			document.addEventListener('deviceready', function() {
				if (navigator.hasOwnProperty('splashscreen')) {
					navigator.splashscreen.hide();
				}
			});
		}])

		.config(function ($translateProvider) {
			$translateProvider.translations('en', {
				'no-connection': {
					'title': 'Oops, no connection available...',
					'body': 'Check your internet connection or try again by pushing \'refresh\'.',
					'button': 'Refresh'
				},
				'system-error': {
					'title': 'Oops, this is embarrassing...',
					'body': 'Something went wrong. Try again by pressing \'refresh\'. ' +
							'If this happens often, please let us know by using the feedback button!',
					'button': 'Refresh',
					'link': 'Feedback'
				},
				'app-out-of-date': {
					'title': 'Update needed',
					'body': 'Your app seems to be out of date! Please visit the app store to continue where you left off.',
					'button': 'App store'
				}
			});
			$translateProvider.translations('nl', {
				'no-connection': {
					'title': 'Oeps, geen verbinding...',
					'body': 'Controleer je netwerkverbinding of probeer het nog eens door op \'refresh\' te klikken.',
					'button': 'Refresh'
				},
				'system-error': {
					'title': 'Oeps, dit is gênant...',
					'body': 'Er is iets fout gegaan. Probeer het nog eens door op \'refresh\' te klikken.' +
							'Mocht dit vaker gebeuren, laat het ons weten door middel van de feedback button!',
					'button': 'Refresh',
					'link': 'Feedback'
				},
				'app-out-of-date': {
					'title': 'Update vereist',
					'body': 'Deze app is niet up-to-date! Ga naar de app store en download de nieuwste versie om verder te gaan.',
					'button': 'App store'
				}
			});

			$translateProvider.preferredLanguage('en');
		})

		.config(['$compileProvider', function($compileProvider) {
				$compileProvider.aHrefSanitizationWhitelist(/^\s*(https?|ftp|mailto|itms-apps|market):/);
			}
		])

		.controller('AppController', ['$scope', '$location', function($scope, $location) {

			$scope.noConnection = ($location.search().reason === 'no-connection') ? true : false ;
			$scope.systemError = ($location.search().reason === 'system-error') ? true : false ;
			$scope.appOutOfDate = ($location.search().reason === 'app-out-of-date') ? true : false ;
			$scope.feedbackurl = 'mailto:' + $location.search().feedbackemail +
								 '?subject=Swipe n Shop feedback' +
								 '&body=My app version: ' + $location.search().appversion + '_' + $location.search().codeversion;

			if (window.hasOwnProperty('cordova')) {
				$scope.store = (window.cordova.platformId === 'android') ?
					$location.search().playstore :
					$location.search().appstore ;
			}

			$scope.refresh = function() {
				window.location.href = '../index.html';
			};

			$scope.mailfeedback = function() {
				window.open($scope.feedbackurl, '_blank', 'location=no');
			};

			$scope.appStore = function() {
				if (window.hasOwnProperty('cordova')) {
					window.open($scope.store, '_blank', 'location=no');
				}
			};
		}]);

})(window, document, window.angular);
